-- | Functions and data for working with Twitter users.
module Twitter.User
where

import Text.XML.HaXml

import Twitter.Xml

-- |Represents a Twitter user, and contains the only attribute thereof
-- that we care about: the screen (user) name.
data User = User { screen_name :: String }
          deriving (Show, Eq)


-- |Create a 'User' from HaXML 'Content'.
user_from_content :: Content i -> (Maybe User)
user_from_content c =
    if (length names) == 0
    then
        Nothing
    else
        case (get_char_data (names !! 0)) of
          Nothing -> Nothing
          (Just content) -> Just (User (content))

    where
    names = user_screen_name c


-- |Get the URL for the given screen name's timeline.
screen_name_to_timeline_url :: String -> String
screen_name_to_timeline_url sn =
    "http://twitter.com/" ++ sn
